"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const fs = require("fs");
const path = require("path");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = core_1.Messages.loadMessages('sfdx-plugin-ci', 'pmd');
const templateFolder = path.resolve(__dirname, '../../../../template/ci/setup/pmd/');
const templateFile = 'apex-ruleset.xml';
class Pmd extends command_1.SfdxCommand {
    async run() {
        if (!fs.existsSync(path.join(path.resolve(this.flags.output)))) {
            this.ux.log(messages.getMessage('folderDoNotExist', [this.flags.output]));
            return null;
        }
        fs.copyFile(path.resolve(templateFolder, templateFile), path.resolve(this.flags.output, templateFile), err => {
            if (err) {
                throw new core_1.SfdxError(messages.getMessage('errorCopyFailed', [templateFile, path.resolve(this.flags.output)]));
            }
            this.ux.log(messages.getMessage('successCopy', [templateFile, path.resolve(this.flags.output)]));
        });
        return null;
    }
}
exports.default = Pmd;
Pmd.description = messages.getMessage('command', [templateFile]);
Pmd.flagsConfig = {
    output: command_1.flags.directory({ char: 'o', description: messages.getMessage('outputFlag'), default: './' })
};
Pmd.requiresProject = false;
//# sourceMappingURL=pmd.js.map