"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const commandExists = require("command-exists");
const fs = require("fs");
const path = require("path");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('sfdx-plugin-ci', 'git');
const GIT_FOLDER = '.git';
const templateFolder = path.resolve(__dirname, '../../../../template/vcs/setup/git/');
const templateFiles = ['gitignore', 'gitattributes'];
const rmTemplateFiles = [{ filename: 'attributes', path: `${GIT_FOLDER}/info` }, { filename: 'config', path: GIT_FOLDER }];
const clis = ['sfdcm', 'smp'];
class Git extends command_1.SfdxCommand {
    async run() {
        if (!fs.existsSync(path.join(path.resolve(this.flags.output)))) {
            this.ux.log(messages.getMessage('folderDoNotExist', [this.flags.output]));
            return null;
        }
        if (!fs.existsSync(path.join(path.resolve(this.flags.output), GIT_FOLDER))) {
            this.ux.log(messages.getMessage('errorNotGitRepo', [this.flags.output]));
            return null;
        }
        templateFiles.forEach(templateFile => {
            fs.copyFile(path.resolve(templateFolder, templateFile), path.resolve(this.flags.output, `.${templateFile}`), err => {
                if (err)
                    throw new core_1.SfdxError(messages.getMessage('errorCopyFailed', [templateFile, path.resolve(this.flags.output)]));
                this.ux.log(messages.getMessage('successCopy', [templateFile, path.resolve(this.flags.output)]));
            });
        });
        if (this.flags['release-manager']) {
            if (clis.every(commandExists.sync)) {
                rmTemplateFiles.forEach(templateFile => {
                    try {
                        fs.appendFileSync(path.resolve(this.flags.output, templateFile.path, templateFile.filename), fs.readFileSync(path.resolve(templateFolder, templateFile.filename)));
                        this.ux.log(messages.getMessage('successCopy', [templateFile.filename, path.resolve(this.flags.output, templateFile.path)]));
                    }
                    catch (error) {
                        throw new core_1.SfdxError(error.getMessage());
                    }
                });
            }
            else {
                this.ux.log(messages.getMessage('prerequisiteNotFullfilled'));
            }
        }
        return null;
    }
}
exports.default = Git;
Git.description = messages.getMessage('command');
Git.flagsConfig = {
    output: command_1.flags.directory({ char: 'o', description: messages.getMessage('outputFlag'), default: './' }),
    'release-manager': command_1.flags.boolean({ char: 'r', description: messages.getMessage('releaseManagerFlag') })
};
Git.requiresProject = false;
//# sourceMappingURL=git.js.map